dddmp package abstract

`Dddmp_Bin2Text()`
  Converts from binary to ASCII format
`Dddmp_Text2Bin()`
  Converts from ASCII to binary format
`Dddmp_cuddAddArrayLoad()`
  Reads a dump file representing the argument ADDs.
`Dddmp_cuddAddArrayStore()`
  Writes a dump file representing the argument Array of ADDs.
`Dddmp_cuddAddLoad()`
  Reads a dump file representing the argument ADD.
`Dddmp_cuddAddStore()`
  Writes a dump file representing the argument ADD.
`Dddmp_cuddBddArrayLoadCnf()`
  Reads a dump file in a CNF format.
`Dddmp_cuddBddArrayLoad()`
  Reads a dump file representing the argument BDDs.
`Dddmp_cuddBddArrayStoreBlif()`
  Writes a dump file representing the argument BDD in a Blif/Exlif notation.
`Dddmp_cuddBddArrayStoreCnf()`
  Writes a dump file representing the argument array of BDDs in CNF format.
`Dddmp_cuddBddArrayStorePrefix()`
  Writes a dump file representing the argument BDD in a prefix notation.
`Dddmp_cuddBddArrayStoreSmv()`
  Writes a dump file representing the argument BDD in a prefix notation.
`Dddmp_cuddBddArrayStore()`
  Writes a dump file representing the argument Array of BDDs.
`Dddmp_cuddBddDisplayBinary()`
  Display a binary dump file in a text file
`Dddmp_cuddBddLoadCnf()`
  Reads a dump file in a CNF format.
`Dddmp_cuddBddLoad()`
  Reads a dump file representing the argument BDD.
`Dddmp_cuddBddStoreBlif()`
  Writes a dump file representing the argument BDD in a Blif/Exlif notation.
`Dddmp_cuddBddStoreCnf()`
  Writes a dump file representing the argument BDD in a CNF format.
`Dddmp_cuddBddStorePrefix()`
  Writes a dump file representing the argument BDD in a prefix notation.
`Dddmp_cuddBddStoreSmv()`
  Writes a dump file representing the argument BDD in a prefix notation.
`Dddmp_cuddBddStore()`
  Writes a dump file representing the argument BDD.
`Dddmp_cuddHeaderLoadCnf()`
  Reads the header of a dump file representing the argument BDDs
`Dddmp_cuddHeaderLoad()`
  Reads the header of a dump file representing the argument BDDs

Last updated on 1040218 17h14